@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
 from nicegui import ui
 import pylab as pl
-import plot_tools as pt
-from experiments import generate_experiment
+from rosys.actors.pathplanning import generate_experiment, plot_tools as pt
 
 robot_renderer, pose, goal, obstacle_map, small_obstacle_map, backward_to_goal = generate_experiment(5.0)
 
