@@ -1,3 +1,4 @@
+from ..helpers import is_test
 from .serial_communication import SerialCommunication
 from .web_communication import WebCommunication
 
@@ -6,6 +7,8 @@ class CommunicationFactory:
 
     @staticmethod
     def create():
+        if is_test:
+            return
         if SerialCommunication.is_possible():
             return SerialCommunication()
         if WebCommunication.is_possible():
