@@ -1,6 +1,7 @@
-import logging
 import json
+import logging
 import os
+
 from .world import World
 
 
@@ -9,15 +10,32 @@ class Persistence:
     def __init__(self, world: World, filepath: str = '~/.rosys/world.json'):
         self.world = world
         self.filepath = os.path.expanduser(filepath)
+        os.makedirs(os.path.dirname(self.filepath), exist_ok=True)
 
     def dump(self) -> dict:
+        robot_excludes = {
+            'velocity',
+            'shape',
+            'parameters',
+            'prediction',
+            'detection',
+            'simulation',
+            'odometry',
+            'current_velocity',
+            'last_movement',
+            'hardware_time',
+            'clock_offset',
+            'carrot',
+        }
         return {
+            'robot': self.world.robot.dict(exclude=robot_excludes),
             'areas': {id: area.dict() for id, area in self.world.areas.items()},
             'obstacles': {id: obstacle.dict() for id, obstacle in self.world.obstacles.items()},
             'usb_cameras': {id: camera.dict() for id, camera in self.world.usb_cameras.items()},
         }
 
     def load(self, world: World):
+        self.world.robot = world.robot
         self.world.areas = world.areas
         self.world.obstacles = world.obstacles
         self.world.usb_cameras = world.usb_cameras
@@ -27,8 +45,8 @@ class Persistence:
         with open(self.filepath, 'w') as f:
             json.dump(self.dump(), f)
 
-    def parse_world(self, obj: dict):
-        return World.parse_obj(obj)
+    def parse_world(self, obj: dict) -> World:
+        return self.world.parse_obj(obj)  # NOTE we use the provided world for parsing to load all attributes
 
     def restore(self):
         if not os.path.exists(self.filepath):
