@@ -1,12 +1,16 @@
 from __future__ import annotations
-from asyncio.exceptions import CancelledError
+
 import asyncio
 import logging
+from asyncio.exceptions import CancelledError
 from typing import Optional, Type
 
-from . import event, task_logger, run, sleep, is_test, Persistence
-from .actors import Actor, Automator, Lizard, Odometer, Steerer, UsbCameraCapture, UsbCameraSimulator, NetworkMonitor, Backup, AsyncioMonitor, GarbageCollector
-from .hardware import Hardware, SimulatedHardware
+from . import Persistence, event, is_test, run, sleep, task_logger
+from .actors import (Actor, AsyncioMonitor, Automator, Backup, CameraProjector,
+                     Detector, DetectorSimulator, GarbageCollector, Lizard,
+                     NetworkMonitor, Odometer, PathPlanner, Steerer,
+                     UsbCameraCapture, UsbCameraSimulator)
+from .hardware import CommunicatingHardware, Hardware, SimulatedHardware
 from .world import World
 
 
@@ -24,12 +28,18 @@ class Runtime:
             self.persistence = persistence or Persistence(self.world)
             self.persistence.restore()
         self.hardware = hardware or SimulatedHardware(self.world)
+        if is_test:
+            assert isinstance(self.hardware, SimulatedHardware), \
+                'real hardware must not be used in tests'
         self.lizard = Lizard(self.hardware)
         self.odometer = Odometer()
         self.steerer = Steerer(self.hardware)
         self.automator = Automator()
+        self.camera_projector = CameraProjector()
         self.asyncio_monitor = AsyncioMonitor()
+        self.detector: Optional[Detector] = None  # NOTE can be set by runtime.with_detector()
         self.actors = [
+            self.camera_projector,
             self.lizard,
             self.odometer,
             self.steerer,
@@ -41,6 +51,7 @@ class Runtime:
             self.with_actors(NetworkMonitor())
         if not is_test:
             self.with_actors(Backup(self.persistence))
+        self.path_planner: Optional[PathPlanner] = None
 
     def with_actors(self, *actors: list[Actor]) -> Runtime:
         '''Adds list of additional actors to runtime.'''
@@ -52,15 +63,42 @@ class Runtime:
         if UsbCameraCapture.is_operable() and not is_test:
             self.with_actors(UsbCameraCapture())
         else:
-            self.with_actors(UsbCameraSimulator())
+            self.usb_camera_simulator = UsbCameraSimulator()
+            self.with_actors(self.usb_camera_simulator)
         return self
 
+    def with_detector(self, real: Detector = Detector(), simulation: DetectorSimulator = DetectorSimulator()) -> Runtime:
+        '''Adds detector to runtime.'''
+        if isinstance(self.hardware, CommunicatingHardware) and not is_test:
+            self.detector = real
+        else:
+            self.detector = simulation
+        self.with_actors(self.detector)
+        return self
+
+    def with_path_planner(self) -> Runtime:
+        '''Adds path planning actor to runtime.'''
+        self.path_planner = PathPlanner()
+        self.with_actors(self.path_planner)
+        return self
+
+    def get_actor(self, type_: Type[Actor]) -> Actor:
+        for a in self.actors():
+            if isinstance(a, type_):
+                return a
+        return None
+
     async def startup(self):
         if self.tasks:
             raise Exception('should be only executed once')
 
         event.register(event.Id.NEW_NOTIFICATION, self.store_notification)
         for actor in self.actors:
+            try:
+                await actor.startup()
+            except:
+                self.log.exception(f'error while starting {actor}')
+                continue
             if actor.interval is not None:
                 self.log.debug(f'starting actor {actor.name} with interval {actor.interval}s')
                 self.tasks.append(task_logger.create_task(self.repeat(actor), name=actor.name))
@@ -72,13 +110,18 @@ class Runtime:
         self.log.debug('startup completed')
 
     async def shutdown(self):
-        await self.hardware.drive(0, 0)
+        try:
+            await self.hardware.drive(0, 0)
+        except:
+            pass
         if not is_test:
             self.persistence.backup()
         [t.cancel() for t in self.tasks]
         if not is_test:
             run.process_pool.shutdown()
-        await asyncio.gather(*[task_logger.create_task(a.tear_down(), name=f'{a.name}.tear_down()') for a in self.actors])
+        for a in self.actors:
+            await a.tear_down()
+        # await asyncio.gather(*[task_logger.create_task(a.tear_down(), name=f'{a.name}.tear_down()') for a in self.actors])
 
     async def repeat(self, actor: Actor):
         while True:
