@@ -1,4 +1,4 @@
 import pytest
 pytest.register_assert_rewrite('rosys.test.helper')  # nopep8
 from .runtime import TestRuntime
-from .helper import assert_point, assert_pose, automate_drive_to
+from .helper import approx, assert_point, assert_pose, automate_drive_to
