@@ -2,6 +2,7 @@ from nicegui.elements.scene_objects import Extrusion, Group, Sphere, Stl
 from nicegui.elements.scene_object3d import Object3D
 from nicegui.ui import Ui
 from ..world import Robot
+from .settings import update_interval
 
 
 class RobotObject(Object3D):
@@ -21,7 +22,7 @@ class RobotObject(Object3D):
             with Group() as self.carrot_group:
                 Sphere(0.03).material('#ff8800')
                 Sphere(0.05).material('#ff8800').move(self.robot.parameters.carrot_offset)
-        self.ui.timer(0.05, self.update)
+        self.ui.timer(update_interval, self.update)
 
     def with_stl(self, url: str, *,
                  x: float = 0, y: float = 0, z: float = 0,
