@@ -1,7 +1,7 @@
 from .area import Area
-from .calibration import Calibration, Intrinsics, Extrinsics
+from .calibration import Calibration, Extrinsics, Intrinsics
 from .camera import Camera
-from .detection import Detection, BoxDetection, PointDetection
+from .detections import BoxDetection, Detection, Detections, PointDetection
 from .image import Image, ImageSize
 from .line import Line
 from .line_segment import LineSegment
