@@ -1,11 +1,14 @@
 from __future__ import annotations
-from pydantic import BaseModel
-from typing import Optional
-import PIL.Image
-import PIL.ImageDraw
+
 import io
 import urllib.parse
-from .detection import Detection
+from typing import Optional
+
+import PIL.Image
+import PIL.ImageDraw
+from pydantic import BaseModel
+
+from .detections import Detections
 
 
 class ImageSize(BaseModel):
@@ -22,7 +25,7 @@ class Image(BaseModel):
     size: ImageSize
     time: float  # World time of recording
     data: Optional[bytes] = None
-    detections: Optional[list[Detection]] = None
+    detections: Optional[Detections] = None
 
     @property
     def url(self) -> str:
@@ -33,13 +36,17 @@ class Image(BaseModel):
         return f'{self.camera_id}/{self.time}'
 
     @staticmethod
-    def create_placeholder(text: str, time: float = None) -> Image:
+    def create_placeholder(text: str, time: float = None, camera_id: str = None) -> Image:
         img = PIL.Image.new('RGB', (260, 200), color=(73, 109, 137))
         d = PIL.ImageDraw.Draw(img)
         d.text((img.width/2-len(text)*3, img.height/2-5), text, fill=(255, 255, 255))
         bytesio = io.BytesIO()
         img.save(bytesio, format='PNG')
-        image = Image(camera_id='no_cam_id', time=time or 0, size=ImageSize(width=img.width, height=img.height))
+        image = Image(
+            camera_id=camera_id or 'no_cam_id',
+            time=time or 0,
+            size=ImageSize(width=img.width, height=img.height)
+        )
         image.data = bytesio.getvalue()
         return image
 
