@@ -1,11 +1,15 @@
 from typing import Optional
+
 from pydantic import Field
-from .image import ImageSize
+
 from .camera import Camera
+from .image import ImageSize
 
 
 class UsbCamera(Camera):
     capture: bool = True
     detect: bool = False
     connected: bool = False
-    resolution: Optional[ImageSize] = Field(None, exclude=True)
+    resolution: Optional[ImageSize] = None
+    exposure: Optional[float] = None
+    color: Optional[str] = None
