@@ -1,6 +1,8 @@
-from pydantic import BaseModel, PrivateAttr
 import time
-from .. import is_test
+
+from pydantic import BaseModel, PrivateAttr
+
+from ..helpers import is_test
 from .area import Area
 from .camera import Camera
 from .obstacle import Obstacle
